@@ -20,26 +20,27 @@
 
 '''Main Veusz executable.'''
 
-from __future__ import division
 import sys
-import os.path
 import signal
 import argparse
+import re
 
 import veusz
-from veusz.compat import czip, cbytes, cstr
 from veusz import qtall as qt
 from veusz import utils
 
+if sys.version_info[0] < 3:
+    raise RuntimeError('Veusz only supports Python 3')
+
 copyr='''Veusz %s
 
-Copyright (C) Jeremy Sanders 2003-2020 <jeremy@jeremysanders.net>
+Copyright (C) Jeremy Sanders 2003-2022 <jeremy@jeremysanders.net>
  and contributors
 Licenced under the GNU General Public Licence (version 2 or greater)
 '''
 
 splashcopyr='''<b><font color="purple">Veusz %s<br></font></b>
-Copyright (C) Jeremy Sanders 2003-2020 and contributors<br>
+Copyright (C) Jeremy Sanders 2003-2022 and contributors<br>
 Licenced under the GPL (version 2 or greater)
 '''
 
@@ -51,7 +52,7 @@ def makeSplash(app):
     '''Make a splash screen logo.'''
 
     splash = qt.QSplashScreen()
-    splash.setStyleSheet("background-color:white;")
+    splash.setStyleSheet("background-color:white; color: black;")
 
     # draw logo on pixmap
     layout = qt.QVBoxLayout(splash)
@@ -66,7 +67,7 @@ def makeSplash(app):
     message.setAlignment(qt.Qt.AlignCenter)
     # increase size of font
     font = message.font()
-    font.setPointSize(font.pointSize()*1.5)
+    font.setPointSizeF(font.pointSize()*1.5)
     message.setFont(font)
     layout.addWidget(message)
     h = qt.QFontMetrics(font).height()
@@ -75,8 +76,10 @@ def makeSplash(app):
     # Center the spash screen
     splash.setGeometry(5, 5, 100, 100)
     screen = qt.QDesktopWidget().screenGeometry()
-    splash.move((screen.width()-layout.sizeHint().width())/2,
-        (screen.height()-layout.sizeHint().height())/2)
+    splash.move(
+        (screen.width()-layout.sizeHint().width())//2,
+        (screen.height()-layout.sizeHint().height())//2
+    )
 
     # make sure dialog goes away - avoid problem if a message box pops
     # up before it is removed
@@ -115,7 +118,7 @@ def export(exports, docs, options):
     # TODO: validate options
     opttxt = ', '.join(options) if options else ''
 
-    for expfn, vsz in czip(exports, docs):
+    for expfn, vsz in zip(exports, docs):
         doc = document.Document()
         ci = document.CommandInterpreter(doc)
         ci.Load(vsz)
@@ -131,7 +134,7 @@ def convertArgsUnicode(args):
         return args
     out = []
     for a in args:
-        if isinstance(a, cbytes):
+        if isinstance(a, bytes):
             out.append(a.decode(enc))
         else:
             out.append(a)
@@ -193,7 +196,7 @@ class VeuszApp(qt.QApplication):
             action='store_true',
             help='(internal - not for external use)')
         parser.add_argument(
-            '--plugin', action='append', metavar='FILE',
+            '--veusz-plugin', action='append', metavar='FILE',
             help='load the plugin from the file given for '
             'the session')
         parser.add_argument(
@@ -307,14 +310,20 @@ class VeuszApp(qt.QApplication):
 
         # add directories to path
         if setting.settingdb['external_pythonpath']:
-            sys.path += setting.settingdb['external_pythonpath'].split(':')
+            # We want a list of items separated by colons
+            # Unfortunately on windows there can be a colon and drive letter,
+            # so we avoid splitting colons which look like a:\foo or B:/bar
+            parts = re.findall(
+                r'[A-Za-z]:[\\/][^:]+|[^:]+',
+                setting.settingdb['external_pythonpath'])
+            sys.path += list(parts)
 
         # load any requested plugins
-        if args.plugin:
+        if args.veusz_plugin:
             try:
-                document.Document.loadPlugins(pluginlist=args.plugin)
+                document.Document.loadPlugins(pluginlist=args.veusz_plugin)
             except RuntimeError as e:
-                startuperrors.append(cstr(e))
+                startuperrors.append(str(e))
 
         # different modes
         if args.listen:
@@ -354,6 +363,8 @@ def run():
     try:
         qt.QApplication.setAttribute(qt.Qt.AA_EnableHighDpiScaling, True)
         qt.QApplication.setAttribute(qt.Qt.AA_UseHighDpiPixmaps, True)
+        qt.QApplication.setHighDpiScaleFactorRoundingPolicy(
+            qt.QApplication.highDpiScaleFactorRoundingPolicy().PassThrough)
     except AttributeError:
         # old qt versions
         pass
